from setuptools import setup

setup(name='funieest',
      version='0.2',
      description='The funniest joke in the world',
      url='https://github.com/hamadi15/test',
      author='halim hamadi',
      author_email='halim.hamadi@mail.ugm.ac.id',
      license='MIT',
      packages=['funniest'],
      zip_safe=False)